@@ -52,12 +52,12 @@ package com.openexchange.http.grizzly;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
 import java.util.concurrent.atomic.AtomicBoolean;
 import com.openexchange.config.ConfigTools;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.DefaultInterests;
+import com.openexchange.config.Interests;
 import com.openexchange.config.Reloadable;
 import com.openexchange.exception.OXException;
 import com.openexchange.http.grizzly.osgi.Services;
@@ -76,8 +76,6 @@ public class GrizzlyConfig implements Initialization, Reloadable {
 
     private static final GrizzlyConfig instance = new GrizzlyConfig();
 
-    private static final String CONFIGFILE = "server.properties";
-    private static final String[] PROPERTIES = new String[] {"com.openexchange.server.knownProxies"};
     private final PropertyChangeSupport changes = new PropertyChangeSupport(this);
 
     public static GrizzlyConfig getInstance() {
@@ -107,7 +105,7 @@ public class GrizzlyConfig implements Initialization, Reloadable {
     private boolean isCometEnabled = false;
 
     /** The max. number of allowed request parameters */
-    private int maxRequestParameters = 30;
+    private int maxRequestParameters = 1000;
 
     /** Unique backend route for every single backend behind the load balancer */
     private String backendRoute = "OX0";
@@ -192,6 +190,9 @@ public class GrizzlyConfig implements Initialization, Reloadable {
 
     private List<String> enabledCiphers = null;
 
+    /** The Web Socket timeout in milliseconds */
+    private long wsTimeoutMillis;
+
 
     @Override
     public void start() throws OXException {
@@ -222,6 +223,7 @@ public class GrizzlyConfig implements Initialization, Reloadable {
         this.isCometEnabled = configService.getBoolProperty("com.openexchange.http.grizzly.hasCometEnabled", false);
         this.isAbsoluteRedirect = configService.getBoolProperty("com.openexchange.http.grizzly.doAbsoluteRedirect", false);
         this.maxHttpHeaderSize = configService.getIntProperty("com.openexchange.http.grizzly.maxHttpHeaderSize", 8192);
+        this.wsTimeoutMillis = configService.getIntProperty("com.openexchange.http.grizzly.wsTimeoutMillis", 900000);
         this.isSslEnabled = configService.getBoolProperty("com.openexchange.http.grizzly.hasSSLEnabled", false);
         this.keystorePath = configService.getProperty("com.openexchange.http.grizzly.keystorePath", "");
         this.keystorePassword = configService.getProperty("com.openexchange.http.grizzly.keystorePassword", "");
@@ -260,7 +262,7 @@ public class GrizzlyConfig implements Initialization, Reloadable {
         }
         this.httpPort = configService.getIntProperty("com.openexchange.connector.networkListenerPort", 8009);
         this.httpsPort = configService.getIntProperty("com.openexchange.connector.networkSslListenerPort", 8010);
-        this.maxRequestParameters = configService.getIntProperty("com.openexchange.connector.maxRequestParameters", 30);
+        this.maxRequestParameters = configService.getIntProperty("com.openexchange.connector.maxRequestParameters", 1000);
         this.backendRoute = configService.getProperty("com.openexchange.server.backendRoute", "OX0");
         this.echoHeader = configService.getProperty("com.openexchange.servlet.echoHeaderName","X-Echo-Header");
 
@@ -556,6 +558,15 @@ public class GrizzlyConfig implements Initialization, Reloadable {
         return maxHttpHeaderSize;
     }
 
+    /**
+     * Gets the Web Socket timeout in milliseconds
+     *
+     * @return The timeout
+     */
+    public long getWsTimeoutMillis() {
+        return wsTimeoutMillis;
+    }
+
     public boolean isSslEnabled() {
         return isSslEnabled;
     }
@@ -581,10 +592,8 @@ public class GrizzlyConfig implements Initialization, Reloadable {
     }
 
     @Override
-    public Map<String, String[]> getConfigFileNames() {
-        Map<String, String[]> map = new HashMap<String, String[]>(1);
-        map.put(CONFIGFILE, PROPERTIES);
-        return map;
+    public Interests getInterests() {
+        return DefaultInterests.builder().propertiesOfInterest("com.openexchange.server.knownProxies").build();
     }
 
     public void addPropertyListener(PropertyChangeListener listener) {
