@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,6 +66,7 @@ public class RequestWatcherActivator extends HousekeepingActivator {
         super();
     }
 
+    /** The request watcher instance */
     private volatile RequestWatcherServiceImpl requestWatcher;
 
     @Override
@@ -75,27 +76,26 @@ public class RequestWatcherActivator extends HousekeepingActivator {
 
     @Override
     protected void startBundle() throws OXException {
-        final Logger log = org.slf4j.LoggerFactory.getLogger(RequestWatcherActivator.class);
-        log.info("Starting RequestWatcher.");
+        Logger log = org.slf4j.LoggerFactory.getLogger(RequestWatcherActivator.class);
+        log.info("Starting request watcher.");
 
-        Services.setServiceLookup(this);
-
-        final RequestWatcherServiceImpl requestWatcher = new RequestWatcherServiceImpl();
+        RequestWatcherServiceImpl requestWatcher = new RequestWatcherServiceImpl(getService(ConfigurationService.class), getService(TimerService.class));
         this.requestWatcher = requestWatcher;
         registerService(RequestWatcherService.class, requestWatcher);
     }
 
     @Override
     protected void stopBundle() throws Exception {
-        final Logger log = org.slf4j.LoggerFactory.getLogger(RequestWatcherActivator.class);
-        log.info("Stopping RequestWatcher.");
+        Logger log = org.slf4j.LoggerFactory.getLogger(RequestWatcherActivator.class);
+        log.info("Stopping request watcher.");
+
         // Stop the Watcher
-        final RequestWatcherServiceImpl requestWatcher = this.requestWatcher;
+        RequestWatcherServiceImpl requestWatcher = this.requestWatcher;
         if (null != requestWatcher) {
             requestWatcher.stopWatching();
             this.requestWatcher = null;
         }
-        Services.setServiceLookup(null);
+
         super.stopBundle();
     }
 
